@@ -1,6 +1,3 @@
-#ifndef BREEZE_DECORATION_H
-#define BREEZE_DECORATION_H
-
 /*
  * SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
  * SPDX-FileCopyrightText: 2014 Hugo Pereira Da Costa <hugo.pereira@free.fr>
@@ -8,6 +5,8 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
+#pragma once
+
 #include "breeze.h"
 #include "breezesettings.h"
 
@@ -90,7 +89,11 @@ public:
     //@}
 
 public Q_SLOTS:
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    bool init() override;
+#else
     void init() override;
+#endif
 
 private Q_SLOTS:
     void reconfigure();
@@ -108,7 +111,7 @@ private:
     void createButtons();
     void paintTitleBar(QPainter *painter, const QRect &repaintRegion);
     void updateShadow();
-    QSharedPointer<KDecoration2::DecorationShadow> createShadowObject(const float strengthScale, const QColor &outlineColor);
+    std::shared_ptr<KDecoration2::DecorationShadow> createShadowObject(const float strengthScale, const QColor &outlineColor);
     void setScaledCornerRadius();
 
     //*@name border size
@@ -166,48 +169,46 @@ bool Decoration::hasNoSideBorders() const
 
 bool Decoration::isMaximized() const
 {
-    return client().toStrongRef()->isMaximized() && !m_internalSettings->drawBorderOnMaximizedWindows();
+    return client()->isMaximized() && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 
 bool Decoration::isMaximizedHorizontally() const
 {
-    return client().toStrongRef()->isMaximizedHorizontally() && !m_internalSettings->drawBorderOnMaximizedWindows();
+    return client()->isMaximizedHorizontally() && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 
 bool Decoration::isMaximizedVertically() const
 {
-    return client().toStrongRef()->isMaximizedVertically() && !m_internalSettings->drawBorderOnMaximizedWindows();
+    return client()->isMaximizedVertically() && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 
 bool Decoration::isLeftEdge() const
 {
-    const auto c = client().toStrongRef();
+    const auto c = client();
     return (c->isMaximizedHorizontally() || c->adjacentScreenEdges().testFlag(Qt::LeftEdge)) && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 
 bool Decoration::isRightEdge() const
 {
-    const auto c = client().toStrongRef();
+    const auto c = client();
     return (c->isMaximizedHorizontally() || c->adjacentScreenEdges().testFlag(Qt::RightEdge)) && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 
 bool Decoration::isTopEdge() const
 {
-    const auto c = client().toStrongRef();
+    const auto c = client();
     return (c->isMaximizedVertically() || c->adjacentScreenEdges().testFlag(Qt::TopEdge)) && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 
 bool Decoration::isBottomEdge() const
 {
-    const auto c = client().toStrongRef();
+    const auto c = client();
     return (c->isMaximizedVertically() || c->adjacentScreenEdges().testFlag(Qt::BottomEdge)) && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 
 bool Decoration::hideTitleBar() const
 {
-    return m_internalSettings->hideTitleBar() && !client().toStrongRef()->isShaded();
+    return m_internalSettings->hideTitleBar() && !client()->isShaded();
 }
 
 }
-
-#endif
