@@ -7,12 +7,13 @@
 #include "breezehelper.h"
 
 #include "breeze.h"
-#include "breezestyleconfigdata.h"
+#include "breezepropertynames.h"
 
 #include <KColorScheme>
 #include <KColorUtils>
 #include <KIconLoader>
 #include <KWindowSystem>
+#include <qobject.h>
 #if __has_include(<KX11Extras>)
 #include <KX11Extras>
 #endif
@@ -40,30 +41,41 @@ static const qreal highlightBackgroundAlpha = 0.33;
 
 static const auto radioCheckSunkenDarkeningFactor = 110;
 
+PaletteChangedEventFilter::PaletteChangedEventFilter(Helper *helper)
+    : QObject(helper)
+    , _helper(helper)
+{
+}
+
+bool PaletteChangedEventFilter::eventFilter(QObject *watched, QEvent *event)
+{
+    if (event->type() != QEvent::ApplicationPaletteChange || watched != qApp) {
+        return QObject::eventFilter(watched, event);
+    }
+    if (!qApp->property("KDE_COLOR_SCHEME_PATH").isValid()) {
+        return QObject::eventFilter(watched, event);
+    }
+    const auto path = qApp->property("KDE_COLOR_SCHEME_PATH").toString();
+    if (!path.isEmpty()) {
+        KConfig config(path, KConfig::SimpleConfig);
+        KConfigGroup group(config.group(QStringLiteral("WM")));
+        const QPalette palette(QApplication::palette());
+        _helper->_activeTitleBarColor = group.readEntry("activeBackground", palette.color(QPalette::Active, QPalette::Highlight));
+        _helper->_activeTitleBarTextColor = group.readEntry("activeForeground", palette.color(QPalette::Active, QPalette::HighlightedText));
+        _helper->_inactiveTitleBarColor = group.readEntry("inactiveBackground", palette.color(QPalette::Disabled, QPalette::Highlight));
+        _helper->_inactiveTitleBarTextColor = group.readEntry("inactiveForeground", palette.color(QPalette::Disabled, QPalette::HighlightedText));
+    }
+    return QObject::eventFilter(watched, event);
+}
+
 //____________________________________________________________________
 Helper::Helper(KSharedConfig::Ptr config, QObject *parent)
     : QObject(parent)
     , _config(std::move(config))
     , _kwinConfig(KSharedConfig::openConfig("kwinrc"))
     , _decorationConfig(new InternalSettings())
+    , _eventFilter(new PaletteChangedEventFilter(this))
 {
-    if (qApp) {
-        connect(qApp, &QApplication::paletteChanged, this, [=]() {
-            if (!qApp->property("KDE_COLOR_SCHEME_PATH").isValid()) {
-                return;
-            }
-            const auto path = qApp->property("KDE_COLOR_SCHEME_PATH").toString();
-            if (!path.isEmpty()) {
-                KConfig config(path, KConfig::SimpleConfig);
-                KConfigGroup group(config.group("WM"));
-                const QPalette palette(QApplication::palette());
-                _activeTitleBarColor = group.readEntry("activeBackground", palette.color(QPalette::Active, QPalette::Highlight));
-                _activeTitleBarTextColor = group.readEntry("activeForeground", palette.color(QPalette::Active, QPalette::HighlightedText));
-                _inactiveTitleBarColor = group.readEntry("inactiveBackground", palette.color(QPalette::Disabled, QPalette::Highlight));
-                _inactiveTitleBarTextColor = group.readEntry("inactiveForeground", palette.color(QPalette::Disabled, QPalette::HighlightedText));
-            }
-        });
-    }
 }
 
 //____________________________________________________________________
@@ -94,7 +106,7 @@ void Helper::loadConfig()
     _cachedAutoValid = false;
     _decorationConfig->load();
 
-    KConfigGroup globalGroup(_config->group("WM"));
+    KConfigGroup globalGroup(_config->group(QStringLiteral("WM")));
     _activeTitleBarColor = globalGroup.readEntry("activeBackground", palette.color(QPalette::Active, QPalette::Highlight));
     _activeTitleBarTextColor = globalGroup.readEntry("activeForeground", palette.color(QPalette::Active, QPalette::HighlightedText));
     _inactiveTitleBarColor = globalGroup.readEntry("inactiveBackground", palette.color(QPalette::Disabled, QPalette::Highlight));
@@ -102,7 +114,7 @@ void Helper::loadConfig()
 
     if (const QString colorSchemePath = qApp->property("KDE_COLOR_SCHEME_PATH").toString(); !colorSchemePath.isEmpty()) {
         KConfig config(colorSchemePath, KConfig::SimpleConfig);
-        KConfigGroup appGroup(config.group("WM"));
+        KConfigGroup appGroup(config.group(QStringLiteral("WM")));
         _activeTitleBarColor = appGroup.readEntry("activeBackground", _activeTitleBarColor);
         _activeTitleBarTextColor = appGroup.readEntry("activeForeground", _activeTitleBarTextColor);
         _inactiveTitleBarColor = appGroup.readEntry("inactiveBackground", _inactiveTitleBarColor);
@@ -110,6 +122,20 @@ void Helper::loadConfig()
     }
 }
 
+void Helper::installEventFilter(QApplication *app) const
+{
+    if (app) {
+        app->installEventFilter(_eventFilter);
+    }
+}
+
+void Helper::removeEventFilter(QApplication *app) const
+{
+    if (app) {
+        app->removeEventFilter(_eventFilter);
+    }
+}
+
 QColor transparentize(const QColor &color, qreal amount)
 {
     auto clone = color;
@@ -538,7 +564,7 @@ void Helper::renderSidePanelFrame(QPainter *painter, const QRect &rect, const QC
 }
 
 //______________________________________________________________________________
-void Helper::renderMenuFrame(QPainter *painter, const QRect &rect, const QColor &color, const QColor &outline, bool roundCorners, bool isTopMenu) const
+void Helper::renderMenuFrame(QPainter *painter, const QRect &rect, const QColor &color, const QColor &outline, bool roundCorners, Qt::Edges seamlessEdges) const
 {
     painter->save();
 
@@ -551,7 +577,7 @@ void Helper::renderMenuFrame(QPainter *painter, const QRect &rect, const QColor
 
     // We simulate being able to independently adjust corner radii by
     // setting a clip region and then extending the rectangle beyond it.
-    if (isTopMenu) {
+    if (seamlessEdges != Qt::Edges()) {
         painter->setClipRect(rect);
     }
 
@@ -560,9 +586,11 @@ void Helper::renderMenuFrame(QPainter *painter, const QRect &rect, const QColor
         QRectF frameRect(rect);
         qreal radius(frameRadius(PenWidth::NoPen));
 
-        if (isTopMenu) {
-            frameRect.adjust(0, -radius, 0, 0);
-        }
+        frameRect.adjust( //
+            seamlessEdges.testFlag(Qt::LeftEdge) ? -radius : 0,
+            seamlessEdges.testFlag(Qt::TopEdge) ? -radius : 0,
+            seamlessEdges.testFlag(Qt::RightEdge) ? radius : 0,
+            seamlessEdges.testFlag(Qt::BottomEdge) ? radius : 0);
 
         // set pen
         if (outline.isValid()) {
@@ -580,9 +608,12 @@ void Helper::renderMenuFrame(QPainter *painter, const QRect &rect, const QColor
     } else {
         painter->setRenderHint(QPainter::Antialiasing, false);
         QRect frameRect(rect);
-        if (isTopMenu) {
-            frameRect.adjust(0, 1, 0, 0);
-        }
+
+        frameRect.adjust( //
+            seamlessEdges.testFlag(Qt::LeftEdge) ? 1 : 0,
+            seamlessEdges.testFlag(Qt::TopEdge) ? 1 : 0,
+            seamlessEdges.testFlag(Qt::RightEdge) ? -1 : 0,
+            seamlessEdges.testFlag(Qt::BottomEdge) ? -1 : 0);
 
         if (outline.isValid()) {
             painter->setPen(outline);
@@ -1305,9 +1336,7 @@ void Helper::renderTabBarTab(QPainter *painter,
                              qreal animation) const
 {
     bool enabled = stateProperties.value("enabled", true);
-    bool visualFocus = stateProperties.value("visualFocus");
     bool hovered = stateProperties.value("hovered");
-    bool down = stateProperties.value("down");
     bool selected = stateProperties.value("selected");
     bool documentMode = stateProperties.value("documentMode");
     bool north = stateProperties.value("north");
@@ -1448,8 +1477,7 @@ void Helper::renderArrow(QPainter *painter, const QRect &rect, const QColor &col
         break;
     }
 
-    arrow.translate(rect.x() + (rect.width() - size) / 2.0,
-                    rect.y() + (rect.height() - size) / 2.0);
+    arrow.translate(rect.x() + (rect.width() - size) / 2.0, rect.y() + (rect.height() - size) / 2.0);
 
     painter->save();
     painter->setRenderHints(QPainter::Antialiasing);
@@ -1713,7 +1741,7 @@ bool Helper::shouldDrawToolsArea(const QWidget *widget) const
     static bool isAuto = false;
     static QString borderSize;
     if (!_cachedAutoValid) {
-        KConfigGroup kdecorationGroup(_kwinConfig->group("org.kde.kdecoration2"));
+        KConfigGroup kdecorationGroup(_kwinConfig->group(QStringLiteral("org.kde.kdecoration2")));
         isAuto = kdecorationGroup.readEntry("BorderSizeAuto", true);
         borderSize = kdecorationGroup.readEntry("BorderSize", "Normal");
         _cachedAutoValid = true;
@@ -1743,4 +1771,17 @@ bool Helper::shouldDrawToolsArea(const QWidget *widget) const
     }
     return true;
 }
+
+Qt::Edges Helper::menuSeamlessEdges(const QWidget *widget)
+{
+    if (widget) {
+        auto edges = widget->property(PropertyNames::menuSeamlessEdges).value<Qt::Edges>();
+        // Fallback to older property
+        if (edges == Qt::Edges() && widget->property(PropertyNames::isTopMenu).toBool()) {
+            edges = Qt::TopEdge;
+        }
+        return edges;
+    }
+    return Qt::Edges();
+}
 }
