@@ -87,6 +87,9 @@ public:
     //* application polishing
     void polish(QApplication *) override;
 
+    //* application unpolishing
+    void unpolish(QApplication *) override;
+
     //* polish scrollarea
     void polishScrollArea(QAbstractScrollArea *);
 
