@@ -1,5 +1,4 @@
-#ifndef breezetoolsareamanager_h
-#define breezetoolsareamanager_h
+#pragma once
 
 #include "breezehelper.h"
 #include "breezestyle.h"
@@ -67,5 +66,3 @@ public:
     bool hasHeaderColors();
 };
 }
-
-#endif
